==> hqsoft_core-0.0.81.tar.gz: lib/core_base/utility/common.dart <==
import 'dart:io';

import 'package:connectivity/connectivity.dart';
import 'package:device_info/device_info.dart';
import 'package:flutter/material.dart';
import 'package:money2/money2.dart';

class HexColor extends Color {
  static int _getColorFromHex(String hexColor) {
    hexColor = hexColor.toUpperCase().replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    return int.parse(hexColor, radix: 16);
  }

  HexColor(final String hexColor) : super(_getColorFromHex(hexColor));
  static final Color lineSeparate = HexColor("E1E5EB");
  static final Color transparent = Color(0x00000000);
}

class NumberFormat {
  //https://pub.dev/packages/money2
  static String formatTwoDigit(dynamic num) {
    //US dollars which have 0 digits after the decimal place.
    final Currency currency = Currency.create('USD', 0);
    Money numberResult = Money.fromInt(num.toInt(), code: currency.code);
    return numberResult.format("#,###");
  }

  static String formatDynamic(dynamic num, int decimal) {
    //US dollars which have 2 digits after the decimal place.
    final Currency currency = Currency.create('USD', decimal);
    Money numberResult = Money.from(num, code:currency.code);
    return numberResult.format("#,###.##");
  }

  static String format(int num, String format) {
    final Currency currency = Currency.create('USD', 2);
    Money numberResult = Money.fromInt(num, code:currency.code);
    return numberResult.format(format);
  }
}

class NetworkCheck {
  Future<bool> check() async {
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      return true;
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return true;
    }
    return false;
  }

  Future<bool> checkNetwork() async {
    var status = await check();
    return status;
  }

  dynamic checkInternet(Function func) {
    check().then((internet) {
      if (internet != null && internet) {
        func(true);
      } else {
        func(false);
      }
    });
  }
}

class DeviceScreen {
  static getInforDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      var systemName = iosInfo.systemName;
      var version = iosInfo.systemVersion;
      var name = iosInfo.name;
      var model = iosInfo.model;
      print('$systemName $version, $name $model');
      // iOS 13.1, iPhone 11 Pro Max iPhone
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      var release = androidInfo.version.release;
      var sdkInt = androidInfo.version.sdkInt;
      var manufacturer = androidInfo.manufacturer;
      var model = androidInfo.model;
      print('Android $release (SDK $sdkInt), $manufacturer $model');
      // Android 9 (SDK 28), Xiaomi Redmi Note 7
    }
  }

  static getVersionDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.systemVersion;
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      return androidInfo.version.release;
    }
  }

  static isiPad() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.model == "iPad";
    }
    return false;
  }

  static getModelDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.model;
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      return androidInfo.manufacturer;
    }
  }

  static getModelNameDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.name;
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      return androidInfo.model;
    }
  }
}

class DefaultImagesEmpty {
  static Widget defaultImageEmptySize(double width, double height) {
    return Image.asset(
      'assets/images/default_image.png',
      width: width,
      height: height,
    );
  }
}

==> hqsoft_core-0.0.83.tar.gz: lib/core_base/utility/common.dart <==
import 'dart:io';

import 'package:connectivity/connectivity.dart';
import 'package:device_info/device_info.dart';
import 'package:flutter/material.dart';
import 'package:money2/money2.dart';

class HexColor extends Color {
  static int _getColorFromHex(String hexColor) {
    hexColor = hexColor.toUpperCase().replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    return int.parse(hexColor, radix: 16);
  }

  HexColor(final String hexColor) : super(_getColorFromHex(hexColor));
  static final Color lineSeparate = HexColor("E1E5EB");
  static final Color transparent = Color(0x00000000);
}

class NumberFormat {
  //https://pub.dev/packages/money2
  static String formatTwoDigit(dynamic num) {
    //US dollars which have 0 digits after the decimal place.
    final Currency currency = Currency.create('USD', 0);
    Money numberResult = Money.fromInt(num.toInt(), currency);
    return numberResult.format("#,###");
  }

  static String formatDynamic(dynamic num, int decimal) {
    //US dollars which have 2 digits after the decimal place.
    final Currency currency = Currency.create('USD', decimal);
    Money numberResult = Money.from(num, currency);
    return numberResult.format("#,###.##");
  }

  static String format(int num, String format) {
    final Currency currency = Currency.create('USD', 2);
    Money numberResult = Money.fromInt(num, currency);
    return numberResult.format(format);
  }
}

class NetworkCheck {
  Future<bool> check() async {
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      return true;
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return true;
    }
    return false;
  }

  Future<bool> checkNetwork() async {
    var status = await check();
    return status;
  }

  dynamic checkInternet(Function func) {
    check().then((internet) {
      if (internet != null && internet) {
        func(true);
      } else {
        func(false);
      }
    });
  }
}

class DeviceScreen {
  static getInforDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      var systemName = iosInfo.systemName;
      var version = iosInfo.systemVersion;
      var name = iosInfo.name;
      var model = iosInfo.model;
      print('$systemName $version, $name $model');
      // iOS 13.1, iPhone 11 Pro Max iPhone
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      var release = androidInfo.version.release;
      var sdkInt = androidInfo.version.sdkInt;
      var manufacturer = androidInfo.manufacturer;
      var model = androidInfo.model;
      print('Android $release (SDK $sdkInt), $manufacturer $model');
      // Android 9 (SDK 28), Xiaomi Redmi Note 7
    }
  }

  static getVersionDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.systemVersion;
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      return androidInfo.version.release;
    }
  }

  static isiPad() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.model == "iPad";
    }
    return false;
  }

  static getModelDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.model;
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      return androidInfo.manufacturer;
    }
  }

  static getModelNameDevice() async {
    if (Platform.isIOS) {
      var iosInfo = await DeviceInfoPlugin().iosInfo;
      return iosInfo.name;
    } else if (Platform.isAndroid) {
      var androidInfo = await DeviceInfoPlugin().androidInfo;
      return androidInfo.model;
    }
  }
}

class DefaultImagesEmpty {
  static Widget defaultImageEmptySize(double width, double height) {
    return Image.asset(
      'assets/images/default_image.png',
      width: width,
      height: height,
    );
  }
}
